#! /bin/sh

# Test representation of a table with URLs

TMP_DIR="${TMPDIR}"

test -z "${LIB_DIR}" && LIB_DIR=lib

SCRIPT_BASE=`basename $0 | sed "s/_[0-9]*\.sh$//"`

BASENAME=$(basename $0 .pm)

#BEGIN DEPEND------------------------------------------------------------------

INPUT_SCRIPT="${BIN_DIR}/${SCRIPT_BASE}"

#END DEPEND--------------------------------------------------------------------

set -ue
## set -x

test -z "${TMP_DIR}" && TMP_DIR="/tmp"
TMP_DIR="${TMP_DIR}/tmp-${BASENAME}-$$"
mkdir "${TMP_DIR}"

# To make the trap portable between bash and dash, we need to trap
# "signal" 0 ("EXIT") and rely on it for the cleanup:
## trap "rm -rf '${TMP_DIR}'" 0 1 2 3 15
trap "rm -rf '${TMP_DIR}'" EXIT
trap "exit 1" HUP INT QUIT TERM

TMP_DB_MAIN="${TMP_DIR}/test4fk.db"
TMP_DB_META="${TMP_DIR}/restful.db"
TMP_DB_MAIN_ABS=$(cd $(dirname ${TMP_DB_MAIN}); pwd)/test4fk.db

sqlite3 ${TMP_DB_MAIN} < tests/inputs/samples-r92.sql
sqlite3 ${TMP_DB_MAIN} <<END
    create table related_sample (
        id integer primary key not null,
        uuid char(36) not null,
        revision_id int default null,
        primary_sample_id integer references sample(id),
        related_sample_id integer references sample(id) );
END
sqlite3 ${TMP_DB_MAIN} <<END
    insert into revision (id, uuid, timestamp)
        values (1, '55bb4b09-8daa-4799-8ad5-ddf20ac58bf3', '2000-01-01');
    insert into revision (id, uuid, timestamp)
        values (2, '55bb4b09-8dad-4722-8ad5-ddf20ac58bf3', '2000-01-02');
    insert into revision (id, uuid, timestamp)
        values (3, '55bb4b09-7dad-4722-8ad5-ddf20ac58bf3', '2000-01-03');
    insert into sample (id, SolsaID, uuid, name, revision_id)
        values (1, 'XX-TEST-0001', '55bb4b09-8dab-478e-8ad5-ddf20ac58bf3', 'primary sample', 1);
    insert into sample (id, SolsaID, uuid, name, revision_id)
        values (2, 'XX-TEST-0002', '55bb4b09-8dd-478e-8ad5-ddf20ac58bf3', 'related sample', 2);
    insert into related_sample (id, uuid, primary_sample_id, related_sample_id, revision_id)
        values (1, '55bb4b09-3dd-478e-8ad5-ddf20ac58bf3', 1, 2, 3);
END

sqlite3 ${TMP_DB_META} < sql/metatables.sql
sqlite3 ${TMP_DB_META} < tests/inputs/samples-metadata-r92.sql
sqlite3 ${TMP_DB_META} "update description set dbname = '${TMP_DB_MAIN_ABS}'"

export TMP_DB_MAIN

sqlite3 ${TMP_DB_MAIN} "select * from natural_sample"

perl <<'END'
#! /usr/bin/env perl

# Test package that computes default database settings:

use strict;
use warnings;
use utf8;
use Data::Dumper;

use lib 'lib';
use Database;

binmode( STDOUT, "utf8" );

$Data::Dumper::Sortkeys = 1;
$Data::Dumper::Indent   = 1;

my $db_settings = {
    content_db => {
        DB => $ENV{TMP_DB_MAIN},
        engine => 'SQLite'            
    }
};

my $db = Database->new( $db_settings );
$db->connect();

my $data = $db->get_record_descriptions( 'sample', { record_id => 1 } );
print Dumper $data->[0]{'related_tables'}{'related_sample'};

END

sqlite3 ${TMP_DB_MAIN} "select * from natural_sample"

# Temporary directory will be deleted by the trap.
