#!/bin/bash

# Test package that computes default database settings

TMP_DIR="${TMPDIR}"

test -z "${LIB_DIR}" && LIB_DIR=lib

SCRIPT_BASE=`basename $0 | sed "s/_[0-9]*\.sh$//"`

BASENAME=$(basename $0 .pm)

#BEGIN DEPEND------------------------------------------------------------------

INPUT_SCRIPT="${LIB_DIR}/${SCRIPT_BASE}"

#END DEPEND--------------------------------------------------------------------

set -ue
## set -x

test -z "${TMP_DIR}" && TMP_DIR="/tmp"
TMP_DIR="${TMP_DIR}/tmp-${BASENAME}-$$"
mkdir "${TMP_DIR}"

# To make the trap portable between bash and dash, we need to trap
# "signal" 0 ("EXIT") and rely on it for the cleanup:
## trap "rm -rf '${TMP_DIR}'" 0 1 2 3 15
trap "rm -rf '${TMP_DIR}'" EXIT
trap "exit 1" HUP INT QUIT TERM

TMP_DB_MAIN="${TMP_DIR}/test4fk.db"
TMP_DB_META="${TMP_DIR}/restful.db"

sqlite3 ${TMP_DB_MAIN} < tests/inputs/samples-r92.sql
sqlite3 ${TMP_DB_META} < sql/metatables.sql

export TMP_DB_MAIN

perl <<'END' |
#! /usr/bin/env perl

use strict;
use warnings;
use utf8;

use lib 'lib';
use Database;

binmode( STDOUT, "utf8" );

my $db_settings = {
    content_db => {
        DB => $ENV{TMP_DB_MAIN},
        engine => 'SQLite'            
    }
};

my $db = Database->new( $db_settings );
$db->connect();

$\ = "\n";
print $db->metatables_version;
END
diff - <(grep '^-- metatables\.sql' sql/metatables.sql \
            | head -n1 \
            | cut -d '(' -f 2 \
            | cut -d ')' -f 1)

# Temporary directory will be deleted by the trap.
