#!/bin/bash

# Test package that computes default database settings

TMP_DIR="${TMPDIR}"

test -z "${BIN_DIR}" && BIN_DIR=website/cgi-bin

SCRIPT_BASE=`basename $0 | sed "s/_[0-9]*\.sh$//"`

BASENAME=$(basename $0 .pm)

#BEGIN DEPEND------------------------------------------------------------------

INPUT_SCRIPT="${BIN_DIR}/${SCRIPT_BASE}"

#END DEPEND--------------------------------------------------------------------

set -ue
## set -x

test -z "${TMP_DIR}" && TMP_DIR="/tmp"
TMP_DIR="${TMP_DIR}/tmp-${BASENAME}-$$"
mkdir "${TMP_DIR}"

# To make the trap portable between bash and dash, we need to trap
# "signal" 0 ("EXIT") and rely on it for the cleanup:
## trap "rm -rf '${TMP_DIR}'" 0 1 2 3 15
trap "rm -rf '${TMP_DIR}'" EXIT
trap "exit 1" HUP INT QUIT TERM

TMP_DB_MAIN="${TMP_DIR}/db/test4fk.db"
TMP_DB_META="${TMP_DIR}/db/restful.db"

mkdir $(dirname ${TMP_DB_MAIN})
cp db/test4fk.db ${TMP_DB_MAIN}

ln -s $(pwd)/lib ${TMP_DIR}
ln -s $(pwd)/sql ${TMP_DIR}
ln -s $(pwd)/tools ${TMP_DIR}

mkdir ${TMP_DIR}/website
mkdir ${TMP_DIR}/website/cgi-bin

mkdir -p ${TMP_DIR}/${BIN_DIR}

cp ${INPUT_SCRIPT} ${TMP_DIR}/${BIN_DIR}

# Change dir to the sandbox and run the test:

cd ${TMP_DIR}

sqlite3 ${TMP_DB_MAIN} "ALTER TABLE sample ADD uuid char(36)"
sqlite3 ${TMP_DB_MAIN} "CREATE TABLE related_samples(id integer primary key autoincrement, uuid char(36), sample1_id int, sample2_id int)"
sqlite3 ${TMP_DB_MAIN} "INSERT INTO related_samples VALUES (1, 'fefc3603-fe7a-481c-bc7c-e90c06fc4c3b', 2, 1)"

sqlite3 ${TMP_DB_META} < sql/metatables.sql
sqlite3 ${TMP_DB_META} "INSERT INTO description (id, dbname, dbtable, dbcolumn, coltype) values (1, '${TMP_DB_MAIN}', 'sample', 'id', 'id')"
sqlite3 ${TMP_DB_META} "INSERT INTO description (id, dbname, dbtable, dbcolumn, coltype) values (2, '${TMP_DB_MAIN}', 'related_samples', 'id', 'id')"
sqlite3 ${TMP_DB_META} "INSERT INTO description (id, dbname, dbtable, dbcolumn, coltype, fk_target, relation, visualisation) values (3, '${TMP_DB_MAIN}', 'related_samples', 'sample1_id', 'fk', 1, 'N', 'table')"
sqlite3 ${TMP_DB_META} "INSERT INTO description (id, dbname, dbtable, dbcolumn, coltype, fk_target, relation, visualisation) values (4, '${TMP_DB_MAIN}', 'related_samples', 'sample2_id', 'fk', 1, 'N', 'table')"

sqlite3 ${TMP_DB_MAIN} "SELECT * FROM 'related_samples'"
echo "==="

export REQUEST_URI='/~saulius/restful/website/test4fk.db/sample'
export HTTP_HOST=test.domain.net
export REQUEST_METHOD=post
export REMOTE_USER=writer

${INPUT_SCRIPT} \
    column%3Asample%3A0.SolsaID=VU-TEST-0006 \
    column%3Asample%3A0.related_samples.sample1_id%3A0.sample2_id=2 \
    column%3Asample%3A0.related_samples.sample2_id%3A0.sample1_id=3 \
    Save=Save

sqlite3 ${TMP_DB_MAIN} "SELECT * FROM 'related_samples'"

# Temporary directory will be deleted by the trap.
